# square_common_bl

## about

common business layer for my personal server.

## Installation

```shell
pip install square_common_bl
```

## env

- python>=3.12.0

## changelog

### v1.1.0

- add utils -> get_app_id_v0

### v1.0.0

- initial implementation.

## Feedback is appreciated. Thank you!